@@ -1,11 +1,15 @@
 __author__ = "Karl-Ludwig Besser"
 __email__ = "k.besser@tu-bs.de"
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
 from . import clean_bib_file
+from . import modernize_bib_file
+from . import combine_bib_files
 
 
 __all__ = [
     "__version__",
     "clean_bib_file",
+    "modernize_bib_file",
+    "combine_bib_files"
     ]
